@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import Any
 
 from crowdin_api.api_resources.enums import PatchOperation
 from crowdin_api.api_resources.languages.enums import LanguagesPatchPath
@@ -6,6 +6,6 @@ from crowdin_api.typing import TypedDict
 
 
 class LanguagesPatchRequest(TypedDict):
-    value: Union[str, List[str]]
+    value: Any
     op: PatchOperation
     path: LanguagesPatchPath
